@@ -1,21 +1,7 @@
 /*
-* This file is part of KDevelop
-* Copyright 2010 Milian Wolff <mail@milianw.de>
-*
-* This program is free software; you can redistribute it and/or modify
-* it under the terms of the GNU Library General Public License as
-* published by the Free Software Foundation; either version 2 of the
-* License, or (at your option) any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public
-* License along with this program; if not, write to the
-* Free Software Foundation, Inc.,
-* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    SPDX-FileCopyrightText: 2010 Milian Wolff <mail@milianw.de>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KDEVPLATFORM_PLUGIN_IOPENWITH_H
@@ -46,7 +32,7 @@ public:
     {
         IPlugin* i = ICore::self()->pluginController()->pluginForExtension( QStringLiteral( "org.kdevelop.IOpenWith" ) );
         if (i) {
-            KDevelop::IOpenWith* openWith = i->extension<KDevelop::IOpenWith>();
+            auto* openWith = i->extension<KDevelop::IOpenWith>();
             Q_ASSERT(openWith);
             openWith->openFilesInternal(files);
             return;
